@@ -1,8 +1,9 @@
 package Net::IPAddress::Util::Collection;
 
+use strict;
+use warnings;
 use 5.012;
 use utf8;
-no diagnostics;
 
 require Net::IPAddress::Util;
 require Net::IPAddress::Util::Collection::Tie;
