@@ -1,8 +1,9 @@
 package Net::IPAddress::Util::Range;
 
+use strict;
+use warnings;
 use 5.012;
 use utf8;
-no diagnostics;
 
 use overload (
     '""' => 'as_string',
